PALM-meteo: palmmeteo/runtime.py File Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Namespaces | Functions | Variables
runtime.py File Reference

## Classes
class | palmmeteo.runtime.RuntimeObj

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.runtime

## Functions
| palmmeteo.runtime.myopen (fpath, *args, **kwargs)
| palmmeteo.runtime.basic_init (rt)

## Variables
| palmmeteo.runtime.zstd = None
| palmmeteo.runtime.rt = RuntimeObj()